@@ -6,7 +6,7 @@
 */
 
 /*
-* Phamm - http://phamm.rhx.it - <phamm@rhx.it>
+* Phamm - http://www.phamm.org - <team@phamm.org>
 * Copyright (C) 2004,2008 Alessandro De Zorzi and Mirko Grava
 *
 * This file is part of Phamm.
@@ -44,8 +44,6 @@
 
 function refresh ($url, $force_meta = false, $seconds = 0)
 {
-    global $lang;
-
     // Check the protocol
     if (isset($_SERVER['HTTPS']))
         $PROTOCOL = 'https';
@@ -71,8 +69,9 @@ function refresh ($url, $force_meta = false, $seconds = 0)
         <META HTTP-EQUIV=\"Refresh\" CONTENT=\"$seconds; url=$uri\">
         </head>
         <body>
-        <p>".$lang["refresh_message"]."
-        <a href=\"".$uri."\">link</a></p>
+        <p>";
+	echo _("You will be automatically redirected to a new page within a few seconds.<br/> If this does not happen, please follow the link:")." ".'<a href="'.$uri.'">'._("click here").'</a>';
+	echo "</p>
         </body>
         </html>";
         ob_end_flush ();
@@ -163,13 +162,15 @@ function xml2array ($file)
 * @param array $short Sort Attributes
 **/
 
-function phamm_list ($base_dn,$filter,$attributes,$sort=null)
+function phamm_list ($base_dn,$filter,$attributes=null,$sort=null)
 {
-    global $lang;
     global $connect;
 
     // Do a LDAP search
-    $search = ldap_list($connect,$base_dn,$filter,$attributes);
+    if ($attributes)
+	$search = ldap_list($connect,$base_dn,$filter,$attributes);
+    else
+	$search = ldap_list($connect,$base_dn,$filter);
 
     // Order the results if possible
     if (version_compare(phpversion(), "4.2.0", ">="))
@@ -201,7 +202,6 @@ function phamm_list ($base_dn,$filter,$attributes,$sort=null)
 
 function phamm_search ($base_dn,$filter,$attributes=null,$sort=null)
 {
-    global $lang;
     global $connect;
 
     // Do a LDAP search
@@ -275,16 +275,14 @@ function phamm_modify ($dn,$entry)
 
 function wrong_pw ($password1,$password2,$length=PASSWORD_MIN_LENGHT)
 {
-    global $lang;
-
     if ( $password1 != $password2 )
-        $error_msg = $lang["password_dont_match"];
+        $error_msg = _("Passwords don't match!");
 
     elseif ( strlen($password1) < $length )
-	$error_msg = $lang["password_too_short"];
+	$error_msg = _("Password too short!");
 
     elseif ( !check_syntax ('password',$password1) && $length > 0)
-	$error_msg = $lang["password_contain_special_chars"];
+	$error_msg = _("Password contains special chars");
 
     if (isset($error_msg))
         return $error_msg;
@@ -308,8 +306,6 @@ function wrong_pw ($password1,$password2,$length=PASSWORD_MIN_LENGHT)
 
 function password_hash($password_clear)
 {
-    global $lang;
-
     $enc_type = strtolower(ENC_TYPE);
 
     switch($enc_type)
@@ -486,7 +482,130 @@ function phamm_error ()
 {
     global $connect;
 
-    return ldap_errno($connect).' '.ldap_error($connect);
+    return _("LDAP Error: ").ldap_error($connect).' ('._("Code ").ldap_errno($connect).')';
+}
+
+
+/**
+* Various syntax check (IP address, domain, email address...)
+*
+* @author Alessandro De Zorzi <adezorzi@rhx.it>
+* @todo Check if IP 0 < number <255
+*
+* @param string $type The kind of data
+* @param string $arg The value
+* @param int $length The min length of string
+* @todo name
+* @return bool
+**/
+
+function check_syntax ($type,$arg,$length="0")
+{
+    if (strlen($arg) < $length)
+    {
+        return false;
+    }
+
+    // IP Address
+    if ($type == 'ip')
+    {
+        if (!ereg ("^([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})$", $arg))
+        {
+            return FALSE;
+        }
+
+        /*$numbers = explode('.',$arg);
+
+        foreach ($numbers as $number)
+        {
+        	if ($number > 255)
+        	return FALSE;
+        } */
+
+        else
+        {
+            return TRUE;
+        }
+    }
+
+
+    // DOMAIN
+    elseif ($type == 'domain')
+    {
+        if (!eregi("^([0-9a-z][0-9a-z-]+\.)+[a-z]{2,7}$", $arg))
+        {
+            return FALSE;
+        }
+
+        else
+        {
+            return TRUE;
+        }
+    }
+
+    // ALIAS and ACCOUNT
+    elseif ($type == 'account')
+    {
+        if (!eregi("^[\._a-z0-9-]+$", $arg))
+        {
+            return FALSE;
+        }
+
+        else
+        {
+            return TRUE;
+        }
+    }
+
+    // Password
+    elseif ($type == 'password')
+    {
+        if (!eregi("^[\._a-z0-9-]+$", $arg))
+            return false;
+
+        return true;
+    }
+
+    // Email
+    elseif ($type == 'email')
+    {
+        if (!eregi("^[_\.0-9a-z-]+@([0-9a-z][0-9a-z-]+\.)+[a-z]{2,4}$", $arg))
+            return false;
+
+        return true;
+
+    }
+
+    // Name
+    elseif ($type == 'name')
+    {
+        return true;
+    }
+}
+
+
+/**
+* Open the LDAP connection
+*
+* @author Alessandro De Zorzi <adezorzi AT rhx DOT it>
+**/
+
+function phamm_ldap_connect ()
+{
+    // Open LDAP connection to server
+    $connect = @ldap_connect(LDAP_HOST_NAME,LDAP_PORT)
+               or die ("LDAP connection Failed!");
+    
+    ldap_set_option($connect,LDAP_OPT_PROTOCOL_VERSION,LDAP_PROTOCOL_VERSION);
+
+    // Start TLS session
+    if (LDAP_TLS == 1)
+    {
+	@ldap_start_tls($connect)
+	    or die ("Could not start TLS. Please check your LDAP server configuration.");
+    }
+
+    return $connect;
 }
 
 ?>
