@@ -6,7 +6,7 @@
 */
 
 /*
-* Phamm - http://phamm.rhx.it - <phamm@rhx.it>
+* Phamm - http://www.phamm.org - <team@phamm.org>
 * Copyright (C) 2004,2008 Alessandro De Zorzi and Mirko Grava
 *
 * This file is part of Phamm.
@@ -46,23 +46,4 @@ function locale_set($language)
 	return 'en_GB';
 }
 
-
-/**
-* Load language translation into $lang var (cached in SESSION)
-*
-* @author Alessandro De Zorzi <adezorzi AT rhx DOT it>
-*
-* @param string $language
-* @return array $lang
-**/
-
-function locale_load($language)
-{
-    include ('../en_GB.php');
-
-    if (file_exists('../locales/'.$language.'.php'))
-	include ('../locales/'.$language.'.php');
-
-    return $lang;
-}
 ?>
