@@ -6,7 +6,7 @@
 **/
 
 /*
-* Phamm - http://phamm.rhx.it - <phamm@rhx.it>
+* Phamm - http://www.phamm.org - <team@phamm.org>
 * Copyright (C) 2004,2008 Alessandro De Zorzi and Mirko Grava
 *
 * This file is part of Phamm.
@@ -38,7 +38,6 @@ function plugins_menu ()
 {
     global $plugins;
     global $pv;
-    global $lang;
     global $action;
 
     $tag = "<table><tr>"."\n";
@@ -48,7 +47,7 @@ function plugins_menu ()
         if ($_SESSION["login"]["level"] >= $pv[$plugin]["MINAUTHLEVEL"])
         {
             if ($_SESSION["phamm"]["pn"] == $plugin)
-                $tag .= '<td class="plugin_active">';
+                $tag .= '<td class="pluginActive">';
             else
                 $tag .= '<td class="plugin">';
 
@@ -56,7 +55,8 @@ function plugins_menu ()
             if ($action)
                 $tag .= '&amp;action='.$action;
             $tag .= '">';
-            $tag .= strtoupper($lang["$plugin"]);
+            # @todo
+            $tag .= strtoupper($plugin);
 
             $tag .= '</a>';
 
