@@ -45,7 +45,7 @@ function page_start()
     $tag .= "\t".'<style type="text/css" media="all">@import "./style/phamm/main.css";</style>'."\n";
     $tag .= "\t".'<script type="text/javascript" src="functions.js"></script>'."\n";
     $tag .= '</head>'."\n";
-    $tag .= '<body>'."\n";
+    $tag .= "<body onLoad='disableAutocomplete()'>"."\n";
 
     return $tag;
 }
@@ -508,8 +508,10 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 	// Hide values if SUBORDINATED to another
 	if (isset($attr["SUBORDINATED"]))
 	{
-	    if (isset($myvalues[0][strtolower($subordinated)][0]))    
+	    if (isset($myvalues[0][strtolower($subordinated)][0]))
 		$hidden = ($myvalues[0][strtolower($subordinated)][0] == "TRUE" ? null : 1);
+	    elseif (isset($myvalues[$p_name][strtolower($subordinated)]))
+		$hidden = ($myvalues[$p_name][strtolower($subordinated)] == "TRUE" ? null : 1);
 	    else
 		$hidden = 1;
 	}
@@ -517,6 +519,8 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 	{
 	    if (isset($myvalues[0][strtolower($subordinatedreverse)][0]))
 		$hidden = ($myvalues[0][strtolower($subordinatedreverse)][0] == "FALSE" ? null : 1);
+	    elseif (isset($myvalues[$p_name][strtolower($subordinatedreverse)]))
+		$hidden = ($myvalues[$p_name][strtolower($subordinatedreverse)] == "FALSE" ? null : 1);
 	    else
 		$hidden = 1;
 	}
@@ -766,10 +770,10 @@ function form_add_account_2 ($account_new,$action,$values)
     $tag .= '<td colspan="2"><input type="password" name="password2" value="" size="15" maxlength="15" /></td></tr>'."\n";
 
     $tag .= '<tr><td>'._("Name").'</td>'."\n";
-    $tag .= '<td colspan="2"><input type="text" name="givenname" value="'.$givenName.'" size="15" maxlength="50" /></td></tr>'."\n";
+    $tag .= '<td colspan="2"><input type="text" name="givenname" value="'.stripslashes($givenName).'" size="15" maxlength="50" /></td></tr>'."\n";
 
     $tag .= '<tr><td>'._("Surname").'</td>'."\n";
-    $tag .= '<td colspan="2"><input type="text" name="sn" value="'.$sn.'" size="15" maxlength="50" /></td></tr>'."\n";
+    $tag .= '<td colspan="2"><input type="text" name="sn" value="'.stripslashes($sn).'" size="15" maxlength="50" /></td></tr>'."\n";
     
     $i = 0;
 
@@ -781,7 +785,10 @@ function form_add_account_2 ($account_new,$action,$values)
 	    // Search if the firsh OBJECTCLASSES defined in XML is present
 	    if (in_array($action,array('modify_account','update_account')))
 	    {
-		$show_form = (in_array(key($p_value["ACCOUNT"]["OBJECTCLASSES"]),$values[0]["objectclass"]) ? true : false);
+		if (isset($values[0]["objectclass"]))
+		    $show_form = (in_array(key($p_value["ACCOUNT"]["OBJECTCLASSES"]),$values[0]["objectclass"]) ? true : false);
+		else
+		    $show_form = isset($values[$name]);
 	    }
 	    else
 		$show_form = ($name == $pn || !in_array($pn,$plugins_exclusion) ? true : false);
@@ -936,6 +943,10 @@ function trueorfalse($table,$value,$field,$reverse)
 
 	$tag .= "</select>"."\n\n";
     }
+    else
+    {
+	$tag .= ($value=='TRUE' ? $true_label : $false_label);
+    }
 
     return $tag;
 }
@@ -1043,7 +1054,16 @@ function date_input($name,$current_date,$format='ymd')
 {
     $tag = '';
 
-    list($year,$month,$day) = split("-", $current_date);
+    if(preg_match("/-/", $current_date))
+    {
+	list($year,$month,$day) = split("-", $current_date);
+    }
+    else 
+    {
+	$year = substr($current_date,0,4);
+	$month = substr($current_date,4,2);
+	$day = substr($current_date,6,2);
+    }
 
     // Days
     $tag .= '<select name="'.$name.'[day]">';
@@ -1090,7 +1110,7 @@ function locale_select()
 {
     global $supported_languages;
 
-    $tag = '<form action="'.$_SERVER["PHP_SELF"].'" method="get" name="lang">';
+    $tag = '<form method="get" action="'.$_SERVER["PHP_SELF"].'" name="lang">';
     $tag .= '<select name="language" onchange="document.lang.submit()">'."\n";
 	
     foreach ($supported_languages as $l_k => $l_v)
