@@ -5,4 +5,4 @@
 # sample-mail.ldif
 # sample-pdns.ldif
 # 
-ldapadd -v -x -D "cn=manager,dc=example,dc=tld" -W -h localhost -f $1
+ldapadd -v -x -D "cn=admin,dc=example,dc=tld" -W -h localhost -f $1
