@@ -16,10 +16,8 @@ var s = e.checked ? 'checked' : 'unchecked';
 
 document.getElementById(myId).className='plugin'+s
 
-// alert (e.name + ' is ' + s);
 }
 
-
 function activatePlugin(myId)
 {
     document.getElementById(myId).className='pluginActive';
@@ -29,3 +27,12 @@ function deactivatePlugin(myId)
 {
     document.getElementById(myId).className='pluginNonActive';
 }
+
+function disableAutocomplete()
+{
+    if (!document.getElementById) return false;
+    var f = document.getElementById('login');
+    var u = f.elements[0];
+    f.setAttribute("autocomplete", "off");
+    u.focus();
+}
